<?php
/**
 * Available filters for extending Dabba.
 *
 * @package   Dabba
 * @version   1.0.7
 */

/**
 * Demo import files (local files).
 *
 */
function dabba_merlin_local_import_files() {
    return array(
        array(
            'import_file_name'             => 'Demo Content',
            'local_import_file'            => trailingslashit(get_template_directory()) . 'inc/merlin/demo/demo-content.xml',
            'local_import_widget_file'     => trailingslashit(get_template_directory()) . 'inc/merlin/demo/widgets.wie',
            'local_import_customizer_file' => trailingslashit(get_template_directory()) . 'inc/merlin/demo/customizer.dat',
            'import_preview_image_url'     => 'https://www.example.com/merlin/preview_import_image1.jpg',
            'preview_url'                  => 'https://www.energeticthemes.com/themes/dabba/',
        ),
    );
}
add_filter('merlin_import_files', 'dabba_merlin_local_import_files');

/**
 * Execute custom code after the whole import has finished.
 */
function dabba_merlin_after_import_setup() {
    // Assign menus to their locations.
    $primary_menu   = get_term_by('name', 'Primary Menu', 'nav_menu');
    $footer_menu    = get_term_by('name', 'Footer nav', 'nav_menu');
    $secondary_menu = get_term_by('name', 'Secondary Nav', 'nav_menu');

    set_theme_mod(
        'nav_menu_locations', array(
            'primary'   => $primary_menu->term_id,
            'footer'    => $footer_menu->term_id,
            'social'    => $social_menu->term_id,
            'secondary' => $secondary_menu->term_id,

        )
    );

}
add_action('merlin_after_all_import', 'dabba_merlin_after_import_setup');

/**
 * Custom content for the generated child theme's functions.php file.
 *
 * @param string $output Generated content.
 * @param string $slug Parent theme slug.
 */
function dabba_generate_child_functions_php( $output, $slug ) {
	$slug_no_hyphens = strtolower( preg_replace( '#[^a-zA-Z]#', '', $slug ) );
	$output = "
		<?php
		/**
		 * Theme functions and definitions.
		 */
		function {$slug_no_hyphens}_child_enqueue_styles() {

            wp_enqueue_style( '{$slug}-style' , get_template_directory_uri() . '/style.css', array( 'bootstrap' ) );

		    wp_enqueue_style( '{$slug}-child-style',
		        get_stylesheet_directory_uri() . '/style.css',
		        array( '{$slug}-style' ),
		        wp_get_theme()->get('Version')
		    );
		}
		add_action(  'wp_enqueue_scripts', '{$slug_no_hyphens}_child_enqueue_styles' );\n
	";
	// Let's remove the tabs so that it displays nicely.
	$output = trim( preg_replace( '/\t+/', '', $output ) );
	// Filterable return.
	return $output;
}
add_filter( 'merlin_generate_child_functions_php', 'dabba_generate_child_functions_php', 10, 2 );
